@@ -3,15 +3,18 @@ Native Pendulum DateTime object implementation. This is a copy of the Pendulum D
 CoreSchema implementation. This allows Pydantic to validate the DateTime object.
 """
 
+import pendulum
+
 try:
     from pendulum import Date as _Date
     from pendulum import DateTime as _DateTime
     from pendulum import Duration as _Duration
     from pendulum import parse
-except ModuleNotFoundError:  # pragma: no cover
+except ModuleNotFoundError as e:  # pragma: no cover
     raise RuntimeError(
         'The `pendulum_dt` module requires "pendulum" to be installed. You can install it with "pip install pendulum".'
-    )
+    ) from e
+from datetime import date, datetime, timedelta
 from typing import Any, List, Type
 
 from pydantic import GetCoreSchemaHandler
@@ -68,6 +71,9 @@ class DateTime(_DateTime):
         if isinstance(value, _DateTime):
             return handler(value)
 
+        if isinstance(value, datetime):
+            return handler(DateTime.instance(value))
+
         # otherwise, parse it.
         try:
             data = parse(value)
@@ -126,6 +132,9 @@ class Date(_Date):
         if isinstance(value, _Date):
             return handler(value)
 
+        if isinstance(value, date):
+            return handler(pendulum.instance(value))
+
         # otherwise, parse it.
         try:
             data = parse(value)
@@ -184,6 +193,9 @@ class Duration(_Duration):
         if isinstance(value, _Duration):
             return handler(value)
 
+        if isinstance(value, timedelta):
+            return handler(_Duration(seconds=value.total_seconds()))
+
         # otherwise, parse it.
         try:
             data = parse(value)
